/**
  *  \file client/actions/garemote.cc
  *  \brief Global Actions: Remote Control
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/actions/garemote.h"
#include "cpluslib/format.h"
#include "game/global.h"
#include "game/ship.h"
#include "game/team.h"
#include "ui/msgbox.h"
#include "util/nls.h"

class WGlobalRemoteControlAction::Executer : public WGlobalActionExecuter {
    TRemoteControlVerb verb;
 public:
    Executer(TRemoteControlVerb verb)
        : verb(verb)
        { }
    bool execute(GObject& obj, bool /*lock*/);
    void finish(int obj, int success);
};

WGlobalRemoteControlAction::~WGlobalRemoteControlAction()
{ }

WGlobalActionExecuter*
WGlobalRemoteControlAction::prepare()
{
    static const char*const questions[] = {
        N_("Allow remote control for all affected ships?"),
        N_("Forbid remote control for all affected ships?"),
        N_("Drop remote control for all affected ships?"),
        N_("Request remote control for all affected ships?"),
    };
    if (UIMessageBox(_(questions[verb]), _("Global Actions")).doYesNoDialog()) {
        return new Executer(verb);
    } else {
        return 0;
    }
}

bool
WGlobalRemoteControlAction::Executer::execute(GObject& obj, bool /*lock*/)
{
    if (GShip* sh = dynamic_cast<GShip*>(&obj)) {
        return setRemoteControl(*sh, getDisplayedTurn().getCommands(::getPlayerId()), verb);
    } else {
        return false;
    }
}

void
WGlobalRemoteControlAction::Executer::finish(int /*obj*/, int success)
{
    static const char*const answers[] = {
        N_("Remote control has been allowed for %d ship%!1{s%}."),
        N_("Remote control has been forbidden for %d ship%!1{s%}."),
        N_("Remote control has been dropped for %d ship%!1{s%}."),
        N_("Remote control has been requested for %d ship%!1{s%}."),
    };
    messageBox(format(_(answers[verb]), success), _("Global Actions"));
}
